.. image:: images/logo.png

-------------------------------------

Recommended resources
========================

The following collection of resources are things we have found useful when studying the subject and building the
library.

Textbooks
------------

-    Practical Nonparametric Statistics (1999), by W.J. Conover
-    Survival Analysis (2011), by R.G. Miller.
-    Analysing Survival Data from Clinical Trials and Observational Studies (2004), by E. Marubini and M.G. Valsecchi
-    Graph Theory (2017), by R. Diestel.
-    Chi-squared Goodness-of-fit Tests for Censored Data (2017), by M.S. Nikulin

Articles
------------

-     NetworkGT: A GIS tool for geometric and topological analysis of two-dimensional fracture networks (2018), by B. Nyberg and C.W. Nixon
-     The use of topology in fracture network characterization (2015), by D.J. Sanderson and C.W. Nixon
-     The connectivity of two-dimensional networks of spatially correlated fractures (2002), by T. Manzocchi
-     Damage zone characterization combining scan-line and scan-area analysis on a km-scale Digital Outcrop Model: The Qala Fault (Gozo) (2020), by M. Martinelli et. al.
-     Estimation of Wood Fibre Length Distributions from Censored Data through an EM Algorithm (2006), by I. Svensson

Software
------------

The listing of a software package here does not imply my endorsement, and is only intended to give readers an understanding of the broad range of reliability engineering software packages that are available. It is difficult to find a comprehensive list of software resources since most developers of proprietary software rarely acknowledge the existence of any software other than their own. I have not used most of the paid software listed here due to the high cost, so most of my comments in this section are based purely on the content from their websites.


Online resources
-----------------

-    `Reliability Analytics Toolkit <https://reliabilityanalyticstoolkit.appspot.com/>`_ - a collection of tools which run using the Google App Engine. Includes a `tool <https://reliabilityanalyticstoolkit.appspot.com/weibull_analysis>`_ for fitting a Weibull_2P distribution.
-    `Distributome <http://www.distributome.org/V3/calc/index.html>`_ - Provides PDF and CDF of a large number of probability distributions that can be easily changed using sliders for their parameters. It also includes a quantile / CDF calculator. Similar to the Distribution calculator below.
-    `Distribution Calculator <https://www.randomservices.org/random/apps/SpecialCalculator.html>`_ - Provides PDF and CDF of a large number of probability distributions that can be easily changed using sliders for their parameters. It also includes a quantile / CDF calculator. Similar to Distributome above.
-    `Maintenance optimization <http://www.soft4structures.com/WeibullGRP/JSPageMTN.jsp>`_ - an online calculator for optimal replacement policy (time) under Kijima imperfect repair model.
-    `Wolfram Alpha <https://www.wolframalpha.com/>`_ - an amazing computational knowledge engine. Great for checking your calculations.